/// Asynchronous utilities, needs the "async" feature to be enabled.

mod wait;
pub use wait::{wait, wait_random};

mod generic_codec;
pub use generic_codec::GenericCodec;

#[cfg(feature = "test")]
pub mod test;
